from typing import Any, Dict, MutableMapping, Optional, Union

ClientRequestParams = Union[None, bytes, MutableMapping[str, str]]
DictStrAny = Dict[str, Any]
OptionalDict = Optional[Dict[str, Union[int, str]]]
